==> chaosmesh-model-5.0.3-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/PodChaosSpecBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class PodChaosSpecBuilder extends PodChaosSpecFluentImpl<PodChaosSpecBuilder> implements VisitableBuilder<PodChaosSpec,PodChaosSpecBuilder> {

    PodChaosSpecFluent<?> fluent;
    Boolean validationEnabled;

    public PodChaosSpecBuilder() {
        this(true);
    }

    public PodChaosSpecBuilder(Boolean validationEnabled) {
        this(new PodChaosSpec(), validationEnabled);
    }

    public PodChaosSpecBuilder(PodChaosSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public PodChaosSpecBuilder(PodChaosSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new PodChaosSpec(), validationEnabled);
    }

    public PodChaosSpecBuilder(PodChaosSpecFluent<?> fluent,PodChaosSpec instance) {
        this(fluent, instance, true);
    }

    public PodChaosSpecBuilder(PodChaosSpecFluent<?> fluent,PodChaosSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAction(instance.getAction()); 
        fluent.withContainerName(instance.getContainerName()); 
        fluent.withDuration(instance.getDuration()); 
        fluent.withGracePeriod(instance.getGracePeriod()); 
        fluent.withMode(instance.getMode()); 
        fluent.withScheduler(instance.getScheduler()); 
        fluent.withSelector(instance.getSelector()); 
        fluent.withValue(instance.getValue()); 
        this.validationEnabled = validationEnabled; 
    }

    public PodChaosSpecBuilder(PodChaosSpec instance) {
        this(instance,true);
    }

    public PodChaosSpecBuilder(PodChaosSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withAction(instance.getAction()); 
        this.withContainerName(instance.getContainerName()); 
        this.withDuration(instance.getDuration()); 
        this.withGracePeriod(instance.getGracePeriod()); 
        this.withMode(instance.getMode()); 
        this.withScheduler(instance.getScheduler()); 
        this.withSelector(instance.getSelector()); 
        this.withValue(instance.getValue()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.chaosmesh.v1alpha1.EditablePodChaosSpec build() {
        EditablePodChaosSpec buildable = new EditablePodChaosSpec(fluent.getAction(),fluent.getContainerName(),fluent.getDuration(),fluent.getGracePeriod(),fluent.getMode(),fluent.getScheduler(),fluent.getSelector(),fluent.getValue());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        PodChaosSpecBuilder that = (PodChaosSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> chaosmesh-model-5.4.1-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/PodChaosSpecBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class PodChaosSpecBuilder extends io.fabric8.chaosmesh.v1alpha1.PodChaosSpecFluentImpl<io.fabric8.chaosmesh.v1alpha1.PodChaosSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.chaosmesh.v1alpha1.PodChaosSpec,io.fabric8.chaosmesh.v1alpha1.PodChaosSpecBuilder> {

    io.fabric8.chaosmesh.v1alpha1.PodChaosSpecFluent<?> fluent;
    java.lang.Boolean validationEnabled;

    public PodChaosSpecBuilder() {
        this(true);
    }

    public PodChaosSpecBuilder(java.lang.Boolean validationEnabled) {
        this(new PodChaosSpec(), validationEnabled);
    }

    public PodChaosSpecBuilder(io.fabric8.chaosmesh.v1alpha1.PodChaosSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public PodChaosSpecBuilder(io.fabric8.chaosmesh.v1alpha1.PodChaosSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
        this(fluent, new PodChaosSpec(), validationEnabled);
    }

    public PodChaosSpecBuilder(io.fabric8.chaosmesh.v1alpha1.PodChaosSpecFluent<?> fluent,io.fabric8.chaosmesh.v1alpha1.PodChaosSpec instance) {
        this(fluent, instance, true);
    }

    public PodChaosSpecBuilder(io.fabric8.chaosmesh.v1alpha1.PodChaosSpecFluent<?> fluent,io.fabric8.chaosmesh.v1alpha1.PodChaosSpec instance,java.lang.Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAction(instance.getAction()); 
        fluent.withContainerName(instance.getContainerName()); 
        fluent.withDuration(instance.getDuration()); 
        fluent.withGracePeriod(instance.getGracePeriod()); 
        fluent.withMode(instance.getMode()); 
        fluent.withScheduler(instance.getScheduler()); 
        fluent.withSelector(instance.getSelector()); 
        fluent.withValue(instance.getValue()); 
        this.validationEnabled = validationEnabled; 
    }

    public PodChaosSpecBuilder(io.fabric8.chaosmesh.v1alpha1.PodChaosSpec instance) {
        this(instance,true);
    }

    public PodChaosSpecBuilder(io.fabric8.chaosmesh.v1alpha1.PodChaosSpec instance,java.lang.Boolean validationEnabled) {
        this.fluent = this; 
        this.withAction(instance.getAction()); 
        this.withContainerName(instance.getContainerName()); 
        this.withDuration(instance.getDuration()); 
        this.withGracePeriod(instance.getGracePeriod()); 
        this.withMode(instance.getMode()); 
        this.withScheduler(instance.getScheduler()); 
        this.withSelector(instance.getSelector()); 
        this.withValue(instance.getValue()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.chaosmesh.v1alpha1.EditablePodChaosSpec build() {
        EditablePodChaosSpec buildable = new EditablePodChaosSpec(fluent.getAction(),fluent.getContainerName(),fluent.getDuration(),fluent.getGracePeriod(),fluent.getMode(),fluent.getScheduler(),fluent.getSelector(),fluent.getValue());
        return buildable;
    }

    public boolean equals(java.lang.Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        PodChaosSpecBuilder that = (PodChaosSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
